@@ -9,13 +9,13 @@ from .DataStreamCollection import DataStreamCollection
 from .Fusionbase import Fusionbase
 
 try:
-    _dist = get_distribution('fusionbase')
+    _dist = get_distribution("fusionbase")
     # Normalize case for Windows systems
     dist_loc = os.path.normcase(_dist.location)
     here = os.path.normcase(__file__)
-    if not here.startswith(os.path.join(dist_loc, 'fusionbase')):
+    if not here.startswith(os.path.join(dist_loc, "fusionbase")):
         raise DistributionNotFound
 except DistributionNotFound:
-    __version__ = 'Please install this project with setup.py'
+    __version__ = "Please install this project with setup.py"
 else:
     __version__ = _dist.version
